@@ -11,8 +11,8 @@ import os
 class wordSegmenter:
     def __init__(self, max_encoder_len=34, max_decoder_len=44, latent_dim = 500, embedding_dim=500):
         self.this_dir, this_filename = os.path.split(__file__)
-        path_e2i = os.path.join(self.this_dir, 'e2i_w2s.pkl')
-        path_d2i = os.path.join(self.this_dir, 'd2i_w2s.pkl')
+        path_e2i = os.path.join(self.this_dir, "e2i_w2s.pkl")
+        path_d2i = os.path.join(self.this_dir, "d2i_w2s.pkl")
 
         e2i_file = open(path_e2i, 'rb')
         d2i_file = open(path_d2i, 'rb')
@@ -81,7 +81,7 @@ class wordSegmenter:
         self.training_model.fit([x_tr, y_tr_in], y_tr_out, epochs=ep, callbacks=Callbacks, batch_size=batch_size,
                                 validation_data=(([x_test, y_test_in]), y_test_out))
 
-    def load_model_weights(self, filename = 'Segmenter2.0_bestweights.h5'):
+    def load_model_weights(self, filename = "Segmenter2.0_bestweights.h5"):
         weight_path = os.path.join(self.this_dir, filename)
         self.training_model.load_weights(weight_path)
 
